<?php

/**
 * @author Ahmad Hejazee <mngafa@gmail.com>
 *
 * @file Base class for all access handlers for the Access By File module
 */

/**
 * Access handler base class
 */
abstract class NGSLAccessByFileHandler {
  /**
   * @var array Stores the list of arguments of the handler
   */
  protected $arguments = array();

  /**
   * get the name of access handler
   */
  abstract public function getName();

  /**
   * Add and set a new argument for the handler.
   *
   * @param $name string The name of the argument to add
   * @param $value string The value of the argument
   *
   * @throws NGSLAccessByFileHandler_InsufficientArgs
   */
  public function addArgument($name, $value) {
    $this->arguments[$name] = $value;
  }

  /**
   * Add multiple arguments to the handler at once.
   *
   * @param array $args Keyed array of arguments to add
   */
  public function addArguments(array $args) {
    foreach ($args as $arg_name => $arg_value) {
      $this->addArgument($arg_name, $arg_value);
    }
  }

  /**
   * @param $name
   * @return mixed
   * @throws \NGSLAccessByFileHandler_MissingArgument
   */
  protected function getArg($name) {
    if (array_key_exists($name, $this->arguments)) {
      return $this->arguments[$name];
    }
    else {
      throw new NGSLAccessByFileHandler_MissingArgument($name);
    }
  }

  /**
   * Run the handler with specified arguments and return either TRUE or FALSE
   *
   * @return bool Whether the handler allows access or not
   * @throws \NGSLAccessByFileHandler_MissingArgument
   */
  abstract public function run();
}
