<?php

/**
 * Provides the 'userrole' access handler.
 *
 * @author "Ahmad Hesamzadeh" <mngafa@gmail.com>
 * @file Access handler which is based on user roles
 *
 * Provides ability to set access control according to user roles.
 * For example allow all users of a certain role to download files.
 */

/**
 * Provides the 'userrole' access handler.
 *
 * If the current user has the given role, return TRUE. Otherwise return FALSE.
 * In case of errors, it will also return FALSE.
 *
 * Requires the argument 'role' to be set using addArgument()
 */
class NGSLAccessByFileHandlerUserRole extends NGSLAccessByFileHandler {
  public function getName() {
    return 'userrole';
  }

  /**
   * @return bool
   * @throws \NGSLAccessByFileHandler_MissingArgument
   */
  public function run() {
    $role_name = $this->getArg('role');

    // Get role object from given role name
    $role = user_role_load_by_name($role_name);
    if (!$role) {
      watchdog('nginx_securelink', 'NGSLAccessByFileHandlerUserRole: Role @role does not exist.', array('@role' => $role_name), WATCHDOG_ERROR);

      return FALSE;
    }

    // If current user has the given role, return TRUE.
    return isset($GLOBALS['user']->roles[$role->rid]);
  }
}
